@@ -3,4 +3,4 @@ from . import reddit_auth as RedditAuthentication
 from ._utils.frame_model import FrameType
 from ._api.models import CustomType, MemberState
 from ._api.iconkeys import Snoo, Reaction
-from ._utils._exceptions import *
+from ._utils.exceptions import *
