@@ -1,18 +1,20 @@
-MOBILE_USERAGENT = 'Reddit/Version 2021.20.0/Build 326964/Android 11'
-WEB_USERAGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:85.0) Gecko/20100101 Firefox/85.0'
+MOBILE_USERAGENT = 'Reddit/Version 2021.47.0/Build 394342/Android 12'
+WEB_USERAGENT = 'Mozilla/5.0 (Windows NT 11.0; Win64; x64; rv:85.0) Gecko/20100101 Firefox/90.0'
 OAUTH_CLIENT_ID_B64 = "b2hYcG9xclpZdWIxa2c6"
-USER_AGENT = 'Jand/3.0.144'
-SB_User_Agent = 'Android%2Fc3.0.144'
+USER_AGENT = 'Jand/3.0.168'
+SB_User_Agent = 'Android/c3.0.168'
 SB_ai = '2515BDA8-9D3A-47CF-9325-330BC37ADA13'
 SB_PROXY_CHATMEDIA = 'https://sendbirdproxyk8s.chat.redditmedia.com'
 S_REDDIT = 'https://s.reddit.com'
 OAUTH_REDDIT = 'https://oauth.reddit.com'
 WWW_REDDIT = 'https://old.reddit.com'
 ACCOUNTS_REDDIT = 'https://accounts.reddit.com'
+GQL_REDDIT = 'https://gql.reddit.com'
 
 # ws payloads
 MESG_regular = 'MESG{{"channel_url":"{channel_url}","message":"{text}","data":"{{\\"v1\\":{{\\"preview_collapsed\\":false,\\"embed_data\\":{{}},\\"hidden\\":false,\\"highlights\\":[],\\"message_body\\":\\"{text}\\"}}}}","mention_type":"users","req_id":"{req_id}"}}\n'
 MESG_snoo = 'MESG{{"channel_url":"{channel_url}","message":"","data":"{{\\"v1\\":{{\\"preview_collapsed\\":false,\\"embed_data\\":{{\\"site_name\\":\\"Reddit\\"}},\\"hidden\\":false,\\"snoomoji\\":\\"{snoomoji}\\"}}}}","mention_type":"users","req_id":"{req_id}"}}\n'
-MESG_gif = 'MESG{{"channel_url":"{channel_url}","message":"{gif_url}","data":"{{\\"v1\\":{{\\"highlights\\":[],\\"gif\\":{{\\"url\\":\\"{gif_url}\\",\\"height\\":{height},\\"width\\":{width}}}}}}}","mention_type":"users"}}\n'
+MESG_gif = 'MESG{{"channel_url":"{channel_url}","message":"","data":"{{\\"v1\\":{{\\"highlights\\":[],\\"gif\\":{{\\"url\\":\\"{gif_url}\\",\\"height\\":{height},\\"width\\":{width}}}}}}}","mention_type":"users"}}\n'
+MESG_img = 'MESG{{"channel_url":"{channel_url}","message":"","data":"{{\\"v1\\":{{\\"image\\":{{\\"blurred_url\\":null,\\"title\\":null,\\"mimetype\\":\\"{mimetype}\\",\\"id\\":null,\\"phase\\":\\"done\\",\\"url\\":\\"{img_url}\\",\\"height\\":{height},\\"width\\":{width}}}}}}}","mention_type":"users"}}\n'
 TPST = 'TPST{{"channel_url":"{channel_url}","time":{time},"req_id":""}}\n'
 TPEN = 'TPEN{{"channel_url":"{channel_url}","time":{time},"req_id":""}}\n'
